# What is end-to-end testing?

- A full session replicating how the software should be used in production
- Can be slow
- Only a few tests

## Possible examples

- A notebook batch session where we load raw data and make cellpy data
- A notebook where we process cellpy-data and makes a report
